@@ -393,7 +393,7 @@ public class CreateDatasetForm extends Composite {
 			listOfSteps = Arrays.asList("Edit Common Metadata", "Select Item Resources",
 					"Edit Item Specific Metadata & Publish");
 		} else {
-			listOfSteps = Arrays.asList("Edit Common Metadata", "Edit Item Specific Metadata & Publish");
+			listOfSteps = Arrays.asList("Edit Common Metadata", "Edit Item Specific Metadata & Publish", "Add Resources");
 		}
 
 		this.wizCreator = new WizardCreator(listOfSteps);
